@@ -6,15 +6,14 @@ import queue
 import threading
 import time
 from pickle import dumps as pickle_dumps, loads as pickle_loads
-from time import perf_counter
+from time import monotonic
 from typing import Iterable, Union, Sequence, Callable, Awaitable, Any
 
-from orjson import loads as orjson_loads, dumps as orjson_dumps  # pylint: disable=no-name-in-module
 from overrides import EnforceOverrides
 
 from .util import get_docker_host_ip, is_exception, is_async, MAX_THREADS
 from .remote_exception import RemoteException, exit_err_msg
-from ._streamer import put_in_queue, get_from_queue
+from .streamer import put_in_queue
 
 logger = logging.getLogger(__name__)
 
@@ -37,8 +36,6 @@ logger = logging.getLogger(__name__)
 
 
 def encode(data, encoder):
-    if encoder == 'orjson':
-        return orjson_dumps(data)
     if encoder == 'pickle':
         return pickle_dumps(data)
     if encoder == 'utf8':
@@ -48,8 +45,6 @@ def encode(data, encoder):
 
 
 def decode(data, encoder):
-    if encoder == 'orjson':
-        return orjson_loads(data)
     if encoder == 'pickle':
         return pickle_loads(data)
     if encoder == 'utf8':
@@ -70,7 +65,7 @@ def decode(data, encoder):
 # of bytes, which should be decoded by `decode` according to the 'encoder'.
 
 
-async def write_record(writer, request_id, data, *, encoder: str = 'orjson'):
+async def write_record(writer, request_id, data, *, encoder: str = 'pickle'):
     data_bytes = encode(data, encoder)
     writer.write(f'{request_id} {len(data_bytes)} {encoder}\n'.encode())
     writer.write(data_bytes)
@@ -127,14 +122,14 @@ async def run_unix_server(conn_handler: Callable, path: str):
 
 
 async def open_tcp_connection(host, port, *, timeout=None):
-    t0 = perf_counter()
+    t0 = monotonic()
     while True:
         try:
             reader, writer = await asyncio.open_connection(host, port)
             return reader, writer
         except ConnectionRefusedError:
             if timeout is not None:
-                if perf_counter() - t0 > timeout:
+                if monotonic() - t0 > timeout:
                     raise
             await asyncio.sleep(0.1)
 
@@ -143,14 +138,14 @@ async def open_unix_connection(path: str, *, timeout=None):
     '''
     `path`: the same string that has been used by `run_unix_server`.
     '''
-    t0 = perf_counter()
+    t0 = monotonic()
     while True:
         try:
             reader, writer = await asyncio.open_unix_connection(path)
             return reader, writer
         except (ConnectionRefusedError, FileNotFoundError):
             if timeout is not None:
-                if perf_counter() - t0 > timeout:
+                if monotonic() - t0 > timeout:
                     raise
             await asyncio.sleep(0.1)
 
@@ -247,7 +242,7 @@ class SocketServer(EnforceOverrides):
             self._path = None
             self._host = host
             self._port = int(port)
-        self._backlog = backlog or 64
+        self._backlog = backlog or 512
         self._encoder = 'pickle'  # encoder when sending responses
         self._n_connections = 0
         self._shutdown_path = shutdown_path
@@ -342,11 +337,10 @@ class SocketServer(EnforceOverrides):
         async def _keep_responding():
             while True:
                 try:
-                    req_id, t = reqs.get_nowait()
-                except asyncio.QueueEmpty:
+                    req_id, t = await asyncio.wait_for(reqs.get(), 0.1)
+                except asyncio.TimeoutError:
                     if self.to_shutdown:
                         return
-                    await asyncio.sleep(0.0012)
                     continue
                 try:
                     z = await t
@@ -394,7 +388,7 @@ class SocketClient(EnforceOverrides):
                  port: int = None,
                  num_connections: int = None,
                  connection_timeout: int = 60,
-                 backlog: int = 1024,
+                 backlog: int = 2048,
                  ):
         '''
         `path`, `host`, `port`: either `path` is given (for Unix socket),
@@ -471,13 +465,13 @@ class SocketClient(EnforceOverrides):
             logger.error(msg)
 
         self._prepare_shutdown.set()
-        t0 = perf_counter()
+        t0 = monotonic()
         while not self._pending_requests.empty():
-            if perf_counter() - t0 > self._shutdown_timeout:
+            if monotonic() - t0 > self._shutdown_timeout:
                 break
             time.sleep(0.1)
         while self._active_requests:
-            if perf_counter() - t0 > self._shutdown_timeout:
+            if monotonic() - t0 > self._shutdown_timeout:
                 break
             time.sleep(0.1)
         self._to_shutdown.set()
@@ -509,7 +503,7 @@ class SocketClient(EnforceOverrides):
             to_shutdown = self._to_shutdown
             while True:
                 try:
-                    req_id, data = await read_record(reader, timeout=0.0015)
+                    req_id, data = await read_record(reader, timeout=0.1)
                     req_id = int(req_id)
                 except asyncio.TimeoutError:
                     if to_shutdown.is_set():
@@ -627,7 +621,7 @@ class SocketClient(EnforceOverrides):
                     else:
                         logger.error("exception '%r' happened for input '%s'", e, x)
                         raise
-                t0 = perf_counter()
+                t0 = monotonic()
                 if not put_in_queue(tt, (x, fut, t0), to_shutdown):
                     return
             put_in_queue(tt, nomore, to_shutdown)
@@ -636,14 +630,23 @@ class SocketClient(EnforceOverrides):
         self._tasks.append(t)
 
         while True:
-            z = get_from_queue(tasks, self._to_shutdown, t)
+            try:
+                z = tasks.get(timeout=0.1)
+            except queue.Empty:
+                if t.done():
+                    if t.exception():
+                        raise t.exception()
+                    assert self._to_shutdown.is_set()
+                    break
+                if self._to_shutdown.is_set():
+                    break
+                continue
+
             if z is nomore:
                 break
-            if z is None:
-                break
             x, fut, t0 = z
             try:
-                y = fut.result(timeout=response_timeout - (perf_counter() - t0))
+                y = fut.result(timeout=response_timeout - (monotonic() - t0))
             except Exception as e:
                 if return_exceptions:
                     if return_x:
